You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tinkerpop.apache.org by sp...@apache.org on 2018/07/19 17:41:58 UTC

[39/50] tinkerpop git commit: TINKERPOP-1996 Added IO to imports and javadoc fixes

TINKERPOP-1996 Added IO to imports and javadoc fixes


Project: http://git-wip-us.apache.org/repos/asf/tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/tinkerpop/commit/328737a3
Tree: http://git-wip-us.apache.org/repos/asf/tinkerpop/tree/328737a3
Diff: http://git-wip-us.apache.org/repos/asf/tinkerpop/diff/328737a3

Branch: refs/heads/TINKERPOP-1996
Commit: 328737a371f8a2040d02f9c2dbb06d049ce3c881
Parents: be9db8d
Author: Stephen Mallette <sp...@genoprime.com>
Authored: Thu Jul 12 11:19:10 2018 -0400
Committer: Stephen Mallette <sp...@genoprime.com>
Committed: Thu Jul 19 13:39:30 2018 -0400

----------------------------------------------------------------------
 .../tinkerpop/gremlin/jsr223/CoreImports.java   |  2 ++
 .../tinkerpop/gremlin/process/traversal/IO.java | 34 ++++++++++++++++----
 2 files changed, 30 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/tinkerpop/blob/328737a3/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/jsr223/CoreImports.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/jsr223/CoreImports.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/jsr223/CoreImports.java
index 9d7eb52..72ad47a 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/jsr223/CoreImports.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/jsr223/CoreImports.java
@@ -56,6 +56,7 @@ import org.apache.tinkerpop.gremlin.process.computer.traversal.strategy.optimiza
 import org.apache.tinkerpop.gremlin.process.remote.RemoteConnection;
 import org.apache.tinkerpop.gremlin.process.remote.RemoteGraph;
 import org.apache.tinkerpop.gremlin.process.traversal.Bindings;
+import org.apache.tinkerpop.gremlin.process.traversal.IO;
 import org.apache.tinkerpop.gremlin.process.traversal.Operator;
 import org.apache.tinkerpop.gremlin.process.traversal.Order;
 import org.apache.tinkerpop.gremlin.process.traversal.P;
@@ -184,6 +185,7 @@ public final class CoreImports {
         CLASS_IMPORTS.add(GraphReader.class);
         CLASS_IMPORTS.add(GraphWriter.class);
         CLASS_IMPORTS.add(Io.class);
+        CLASS_IMPORTS.add(IO.class);
         CLASS_IMPORTS.add(IoCore.class);
         CLASS_IMPORTS.add(Storage.class);
         CLASS_IMPORTS.add(GraphMLIo.class);

http://git-wip-us.apache.org/repos/asf/tinkerpop/blob/328737a3/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/IO.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/IO.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/IO.java
index f76c2bc..6668cf1 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/IO.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/IO.java
@@ -23,6 +23,12 @@ import org.apache.tinkerpop.gremlin.process.traversal.dsl.graph.GraphTraversalSo
 import org.apache.tinkerpop.gremlin.structure.Graph;
 import org.apache.tinkerpop.gremlin.structure.io.GraphReader;
 import org.apache.tinkerpop.gremlin.structure.io.GraphWriter;
+import org.apache.tinkerpop.gremlin.structure.io.graphml.GraphMLReader;
+import org.apache.tinkerpop.gremlin.structure.io.graphml.GraphMLWriter;
+import org.apache.tinkerpop.gremlin.structure.io.graphson.GraphSONReader;
+import org.apache.tinkerpop.gremlin.structure.io.graphson.GraphSONWriter;
+import org.apache.tinkerpop.gremlin.structure.io.gryo.GryoReader;
+import org.apache.tinkerpop.gremlin.structure.io.gryo.GryoWriter;
 
 /**
  * Fields that can be provided to the {@link GraphTraversalSource#io(String)} using the
@@ -34,21 +40,37 @@ public class IO {
 
     private IO() {}
 
+    /**
+     * A value to supply to {@link IO#reader} or {@link IO#writer} to indicate the format to use. Using this shorthand
+     * will configure a default {@link GraphSONReader} or {@link GraphSONWriter} respectively,
+     */
     public static final String graphson = "graphson";
+
+    /**
+     * A value to supply to {@link IO#reader} or {@link IO#writer} to indicate the format to use. Using this shorthand
+     * will configure a default {@link GryoReader} or {@link GryoWriter} respectively,
+     */
     public static final String gryo = "gryo";
+
+    /**
+     * A value to supply to {@link IO#reader} or {@link IO#writer} to indicate the format to use. Using this shorthand
+     * will configure a default {@link GraphMLReader} or {@link GraphMLWriter} respectively,
+     */
     public static final String graphml = "graphml";
 
     /**
      * The specific {@link GraphReader} instance to use or the name of the fully qualified classname of such an
      * instance. If this value is not specified then {@link GraphTraversalSource#io(String)} will attempt to construct
      * a default {@link GraphReader} based on the file extension provided to it.
      */
     public static final String reader = Graph.Hidden.hide("tinkerpop.io.reader");
 
     /**
      * The specific {@link GraphWriter} instance to use or the name of the fully qualified classname of such an
      * instance. If this value is not specified then {@link GraphTraversalSource#io(String)} will attempt to construct
      * a default {@link GraphWriter} based on the file extension provided to it.
      */
     public static final String writer = Graph.Hidden.hide("tinkerpop.io.writer");
 }
@@ -34,21 +40,37 @@ public class IO {
 
     /**
-     * The specific {@link GraphReader} instance to use or the name of the fully qualified classname of such an
-     * instance. If this value is not specified then {@link GraphTraversalSource#io(String)} will attempt to construct
-     * a default {@link GraphReader} based on the file extension provided to it.
+     * The specific {@link GraphReader} instance to use, the name of the fully qualified classname of such an
+     * instance or one of {@link IO#graphson}, {@link IO#gryo} or {@link IO#graphml}. If this value is not specified
+     * then {@link GraphTraversalSource#io(String)} will attempt to construct a default {@link GraphReader} based on
+     * the file extension provided to it.
      */
     public static final String reader = Graph.Hidden.hide("tinkerpop.io.reader");
@@ -34,21 +40,37 @@ public class IO {
 
     /**
-     * The specific {@link GraphWriter} instance to use or the name of the fully qualified classname of such an
-     * instance. If this value is not specified then {@link GraphTraversalSource#io(String)} will attempt to construct
-     * a default {@link GraphWriter} based on the file extension provided to it.
+     * The specific {@link GraphWriter} instance to use, the name of the fully qualified classname of such an
+     * instance or one of {@link IO#graphson}, {@link IO#gryo} or {@link IO#graphml}. If this value is not specified
+     * then {@link GraphTraversalSource#io(String)} will attempt to construct a default {@link GraphWriter} based on
+     * the file extension provided to it.
      */
     public static final String writer = Graph.Hidden.hide("tinkerpop.io.writer");